PAWpySeed: kpoint Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
kpoint Struct Reference

`#include <utils.h>`

Collaboration diagram for kpoint:
[legend]

## Public Attributes
short int | up
| spin More...
int | num_waves
| number of plane waves in a band More...
int * | Gs
| plane wave coefficients, in sets of three More...
double * | k
| k-point vector More...
double | weight
| k-point weight More...
int | num_bands
| number of bands More...
band_t ** | bands
| bands with this k-point More...
rayleigh_set_t ** | expansion

## Member Data Documentation

band_t** kpoint::bands

bands with this k-point

rayleigh_set_t** kpoint::expansion

int* kpoint::Gs

plane wave coefficients, in sets of three

double* kpoint::k

k-point vector

int kpoint::num_bands

number of bands

int kpoint::num_waves

number of plane waves in a band

short int kpoint::up

spin

double kpoint::weight

k-point weight

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h